<?php
/**
 * The template for displaying the header
 *
 * Displays all of the head element and everything up until the "site-content" div.
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js">
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width">
	<link rel="profile" href="<?php echo esc_url('http://gmpg.org/xfn/11'); ?>">
	<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
	<?php if ( get_theme_mod('quidus_site_favicon') != '' ) : ?>
		<link rel="shortcut icon" href="<?php echo esc_url(get_theme_mod('quidus_site_favicon')); ?>" />
	<?php endif; ?>
	<!--[if lt IE 9]>
	<script src="<?php echo esc_url( get_template_directory_uri() ); ?>/js/html5.js"></script>
	<![endif]-->

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

	<?php if ( ( get_theme_mod( 'quidus_enable_horizontal_menu' ) == true ) ) : ?>

	<div class="menu-holder">
		
		<div class="horizontal-menu-wrapper">
		
			<header id="masthead" class="site-header">
		
				<div class="site-branding">
				
					<?php if ( get_theme_mod( 'quidus_logo' ) ) : ?>
					
						<div class='site-logo'>
							<a href='<?php echo esc_url( home_url( '/' ) ); ?>' title='<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>' rel='home'><img src='<?php echo esc_url( get_theme_mod( 'quidus_logo' ) ); ?>' alt='<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>'></a>
						</div>
						
					<?php else : 
					
						if ( is_front_page() && is_home() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php else : ?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php endif;

						$description = get_bloginfo( 'description', 'display' );
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo $description; ?></p>
						<?php endif;
						
					endif; ?>
					
					<button class="secondary-toggle"><?php _e( 'Menu and widgets', 'quidus' ); ?></button>
					
				</div><!-- .site-branding -->
			
			</header>
			
			<div class="float-right">
			
			<!-- Navigation menu -->
			
			<?php if ( has_nav_menu( 'primary' ) ) : ?>

				<nav id="site-navigation" class="main-navigation" role="navigation">
					<?php
						// Primary navigation menu.
						wp_nav_menu( array(
							'menu_class'     => 'nav-menu',
							'theme_location' => 'primary',
						) );
					?>
				</nav><!-- .main-navigation -->
			
			<?php endif; ?>
			
			<!-- Social buttons -->
			
			<?php quidus_my_social(); ?>
			
			<!-- Search menu -->
			
			<?php if ( get_theme_mod('quidus_horizontal_menu_search_enable') == true ) : ?>
			
				<div class="toggle-search"><i class="fa fa-search"></i></div>
				<div class="search-expand">
					<div class="search-expand-inner">
						<?php get_search_form(); ?>
					</div>
				</div>
			
			<?php endif; ?>
			
			<?php if ( get_theme_mod('quidus_horizontal_menu_cart_enable') == true ) : ?>
			
				<div class="menu-cart-wrapper">
					
						<?php global $woocommerce; ?>
						<a class="cart-contents fa fa-credit-card" href="<?php echo $woocommerce->cart->get_cart_url(); ?>" title="<?php _e('View your shopping cart', 'woothemes'); ?>">
						<span class="header-menu-cart-count"><?php echo $woocommerce->cart->cart_contents_count;?></span>
						</a>
					
				</div>
			
			<?php endif; ?>
			
			</div>
		
		</div>
		
	</div>
	
	<?php endif; ?>
	
	<?php if ( is_home() and get_theme_mod( 'quidus_header_image' ) ) : ?>

		<div class="scrollme parallax-wrapper">
		
		<?php if ( get_theme_mod('quidus_enable_home_header_text') == true) : ?>
		
			<div class="home-header-text-wrapper animateme" style="z-index:12;" data-when="span" data-easing="linear" data-from="0" data-to="1" data-opacity="0"><?php if ( get_theme_mod('quidus_enable_home_header_text_background', true) == true) : ?><div class="text-box-background" style="z-index:-1;"></div><?php endif; ?>
				<h1 class="home-header-text entry-title"><?php echo esc_attr(get_theme_mod('quidus_home_header_heading')); ?></h1>
				<p><?php echo esc_attr(get_theme_mod('quidus_home_header_description')); ?></p>
			</div>
			
		<?php endif; ?>
		
			<img style="z-index:-1; height:auto; width:100%;" class="animateme" data-when="span" data-easing="linear" data-from="0" data-to="1" data-opacity="1" data-translateY="
			<?php if ( get_theme_mod('quidus_header_image_parallax_translate') == '' ) : echo "225"; else : echo esc_attr(get_theme_mod('quidus_header_image_parallax_translate')); endif; ?>" 
			src="<?php echo esc_url( get_theme_mod( 'quidus_header_image' ) ); ?>" />
		
		</div>
		
	<?php endif; ?>

<div id="page" class="hfeed site">
	<a class="skip-link screen-reader-text" href="#content"><?php _e( 'Skip to content', 'quidus' ); ?></a>
	
	<?php if ( (is_active_sidebar( 'sidebar-1' )) or ( get_theme_mod( 'quidus_enable_horizontal_menu' ) == false )  ) : ?>

		<div id="sidebar" class="sidebar">
		
			<?php if ( get_theme_mod( 'quidus_enable_horizontal_menu' ) == false ) : ?>
			
				<header id="masthead" class="site-header" role="banner">
				
					<div class="site-branding">
					
						<?php if ( get_theme_mod( 'quidus_logo' ) ) : ?>
						
							<div class='site-logo'>
								<a href='<?php echo esc_url( home_url( '/' ) ); ?>' title='<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>' rel='home'><img src='<?php echo esc_url( get_theme_mod( 'quidus_logo' ) ); ?>' alt='<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>'></a>
							</div>
							
						<?php else : 
						
							if ( is_front_page() && is_home() ) : ?>
								<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
							<?php else : ?>
								<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
							<?php endif;

							$description = get_bloginfo( 'description', 'display' );
							if ( $description || is_customize_preview() ) : ?>
								<p class="site-description"><?php echo $description; ?></p>
							<?php endif;
							
						endif; ?>
						
						<button class="secondary-toggle"><?php _e( 'Menu and widgets', 'quidus' ); ?></button>
						
					</div><!-- .site-branding -->
					
				<?php quidus_my_social(); ?>
				
				</header><!-- .site-header -->
				
			<?php endif; ?>	
		
			<?php get_sidebar(); ?>
		</div><!-- .sidebar -->
	
	<?php endif; ?>

	<div id="content" class="site-content">
